/*
 * Jon Howell
 * public domain
 *
 * A driver to test md5.c. Usage: md5test < testfile
 * md5.c was my baseline; I was debugging the operation of
 * MD5.java. During that process, I inserted printfs into md5.c
 * so I could compare values with those being generated by
 * the Java version.
 *
 * The MD5 code in md5.c is lifted from a public domain module distributed
 * with ssh-1.2.22.
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <stdio.h>
#include <errno.h>
#include "md5.h"

/* static int main(int argc, char **argv); */
static void dosum(char *filename, int fd);

int main(int argc, char **argv)
{
	int error = 0;

	if (argc<2) {
		dosum("stdin", 0);
	} else {
		int i;
		int fd;
		char *filename;
		for (i=1; i<argc; i++) {
			filename = argv[i];
			fd = open(filename, O_RDONLY);
			if (fd<0) {
				perror(filename);
				error = errno;
			} else {
				dosum(filename, fd);
				close(fd);
			}
		}
	}
	return error;
}

void dosum(char *filename, int fd)
{
	unsigned char buf[397];
	int rc;
	struct MD5Context md;
	unsigned char out[16];
	int i;
	int len = 0;
	MD5Init(&md);

	while ((rc = read(fd, buf, 397)) > 0) {
		MD5Update(&md, buf, rc);
		len += rc;
	}
	MD5Final(out, &md);

	printf("%10d  ", len);
	for (i=0; i<16; i++) {
		printf("%02x", out[i]);
	}
	printf("  %s\n", filename);
}
